Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(187)

Unified Diff: chrome/browser/autofill/personal_data_manager.h

Issue 10919066: Use BrowserContext as key in API. Switch Autofill to use BC in place of Profile. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/autofill/personal_data_manager.h
diff --git a/chrome/browser/autofill/personal_data_manager.h b/chrome/browser/autofill/personal_data_manager.h
index ca860b335f4debb2119d2db28d09acf416341de5..7a5c071fb39c30d97b60cf7e4451478bc84c0a75 100644
--- a/chrome/browser/autofill/personal_data_manager.h
+++ b/chrome/browser/autofill/personal_data_manager.h
@@ -25,13 +25,16 @@
class AutofillMetrics;
class FormStructure;
class PersonalDataManagerObserver;
-class Profile;
namespace autofill_helper {
void SetProfiles(int, std::vector<AutofillProfile>*);
void SetCreditCards(int, std::vector<CreditCard>*);
}
+namespace content {
+class BrowserContext;
+}
+
// Handles loading and saving Autofill profile information to the web database.
// This class also stores the profiles loaded from the database for use during
// Autofill.
@@ -218,8 +221,8 @@ class PersonalDataManager
const AutofillMetrics* metric_logger() const;
void set_metric_logger(const AutofillMetrics* metric_logger);
- // The profile hosting this PersonalDataManager.
- Profile* profile_;
+ // The browser context this PersonalDataManager is in.
+ content::BrowserContext* browser_context_;
// True if personal data has been loaded from the web database.
bool is_data_loaded_;
@@ -249,7 +252,7 @@ class PersonalDataManager
private:
// Kicks off asynchronous loading of profiles and credit cards.
- void Init(Profile* profile);
+ void Init(content::BrowserContext* context);
// For logging UMA metrics. Overridden by metrics tests.
scoped_ptr<const AutofillMetrics> metric_logger_;

Powered by Google App Engine
This is Rietveld 408576698